@@ -71,7 +71,7 @@ sub _explain
 {
     my $this = shift;
 
-    my ( $repo, $path, $version ) = @$this{qw( repo path version )};
+    my ( $repo, $path, $version, $taropt ) = @$this{qw( repo path version taropt )};
     return if -d "$path/$version";
 
     die "nofind repo file: $repo/$version\n" unless -f "$repo/$version";
@@ -79,7 +79,8 @@ sub _explain
     my $temp = "$path/$version.".time.'.'.$$.'._tmp_explain';
     die "mkdir $temp fail.\n" if syscmd( "mkdir '$temp'" );
 
-    die "untar fail.\n" if syscmd( "tar -zxf '$repo/$version' -C '$temp'" );
+    $taropt ||= '';
+    die "untar fail.\n" if syscmd( "tar $taropt -zxf '$repo/$version' -C '$temp'" );
     die "rename fail.\n" if syscmd( "rm -rf '$path/$version' && mv '$temp' '$path/$version'" );
 }
 
@@ -142,7 +143,9 @@ sub _clean
 sub syscmd
 {
     my $cmd = shift;
-    print "$cmd\n";
+    my $x = $cmd;
+    $x =~ s/\.\d+\.\d+\._tmp_explain/.x.x._tmp_explain/g;
+    print "$x\n";
     my $stat = system $cmd;
     warn "ERROR: $!\n" if $stat;
     return $stat;
